from py_viptela.api.config.builder.lists import app
from py_viptela.api.config.builder.lists import aspath
from py_viptela.api.config.builder.lists import color
from py_viptela.api.config.builder.lists import community
from py_viptela.api.config.builder.lists import datafqdnall
from py_viptela.api.config.builder.lists import dataprefix
from py_viptela.api.config.builder.lists import dataprefix6
from py_viptela.api.config.builder.lists import dataprefixall
from py_viptela.api.config.builder.lists import disc
from py_viptela.api.config.builder.lists import expcommunity
from py_viptela.api.config.builder.lists import extcommunity
from py_viptela.api.config.builder.lists import fax
from py_viptela.api.config.builder.lists import forwarding
from py_viptela.api.config.builder.lists import fqdn
from py_viptela.api.config.builder.lists import ips
from py_viptela.api.config.builder.lists import list
from py_viptela.api.config.builder.lists import localdomainname
from py_viptela.api.config.builder.lists import media
from py_viptela.api.config.builder.lists import modem
from py_viptela.api.config.builder.lists import port
from py_viptela.api.config.builder.lists import prefix
from py_viptela.api.config.builder.lists import prefix6
from py_viptela.api.config.builder.lists import prefixall
from py_viptela.api.config.builder.lists import protocol
from py_viptela.api.config.builder.lists import site
from py_viptela.api.config.builder.lists import tloc
from py_viptela.api.config.builder.lists import translationprofile
from py_viptela.api.config.builder.lists import translationrule
from py_viptela.api.config.builder.lists import trunkgroup
from py_viptela.api.config.builder.lists import vpn
from py_viptela.api.config.builder.lists import zone


def activateContainerOnRemoteHost(vmanage, containerName, url, hostIp, checksum):
    """
    Activate container on remote host
    
    Parameters:
    containerName	 (string):	Container name
	url	 (string):	Container image URL
	hostIp	 (string):	Container host IP
	checksum	 (string):	Container image checksum
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/container-manager/activate/{containerName}?url={url}&hostIp={hostIp}&checksum={checksum}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def deActivateContainer(vmanage, containerName, hostIp):
    """
    Deactivate container on remote host
    
    Parameters:
    containerName	 (string):	Container name
	hostIp	 (string):	Container host IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/container-manager/deactivate/{containerName}?hostIp={hostIp}"
    response = vmanage.apiCall("POST", endpoint)
    return response
def doesValidImageExist(vmanage, containerName):
    """
    Get container image checksum
    
    Parameters:
    containerName	 (string):	Container name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/container-manager/doesValidImageExist/{containerName}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getContainerInspectData(vmanage, containerName, hostIp):
    """
    Get container inspect data
    
    Parameters:
    containerName	 (string):	Container name
	hostIp	 (string):	Container host IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/container-manager/inspect/{containerName}?hostIp={hostIp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getContainerSettings(vmanage, containerName, hostIp):
    """
    Get container settings
    
    Parameters:
    containerName	 (string):	Container name
	hostIp	 (string):	Container host IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/container-manager/settings/{containerName}?hostIp={hostIp}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getChecksum(vmanage):
    """
    Get container image checksum
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/checksum"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCustomApp(vmanage):
    """
    Displays the user-defined applications
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/customapps"
    response = vmanage.apiCall("GET", endpoint)
    return response
def activateContainer(vmanage, containertaskconfig, taskId):
    """
    Activate container
    
    Parameters:
    containertaskconfig:	Container task config
	taskId	 (string):	Task Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/task/{taskId}"
    response = vmanage.apiCall("POST", endpoint, containertaskconfig)
    return response
def testLoadBalancer(vmanage):
    """
    Test SD_AVC load balancer
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sdavc/test"
    response = vmanage.apiCall("POST", endpoint)
    return response



def generateSecurityTemplateList(vmanage, mode):
    """
    Generate template list
    
    Parameters:
    mode	 (string):	Mode
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security?mode={mode}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createSecurityTemplate(vmanage, policytemplate):
    """
    Create Template
    
    Parameters:
    policytemplate:	Policy template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security"
    response = vmanage.apiCall("POST", endpoint, policytemplate)
    return response

def getSecurityTemplate(vmanage, policyId):
    """
    Get Template
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/definition/{policyId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSecurityPolicyDeviceList(vmanage):
    """
    Get device list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/devices"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceListById(vmanage, policyId):
    """
    Get device list by Id
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/devices/{policyId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editTemplateWithLenientLock(vmanage, policytemplate, policyId):
    """
    Edit Template
    
    Parameters:
    policytemplate:	Policy template
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/staging/{policyId}"
    response = vmanage.apiCall("PUT", endpoint, policytemplate)
    return response

def generateSecurityPolicySummary(vmanage):
    """
    Generate security policy summary
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/summary"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSecurityTemplatesForDevice(vmanage, deviceModel):
    """
    Get templates that map a device model
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/{deviceModel}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editSecurityTemplate(vmanage, policytemplate, policyId):
    """
    Edit Template
    
    Parameters:
    policytemplate:	Policy template
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/{policyId}"
    response = vmanage.apiCall("PUT", endpoint, policytemplate)
    return response

def deleteSecurityTemplate(vmanage, policyId):
    """
    Delete Template
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/security/{policyId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getInterface(vmanage, vpnId, ifname, af, deviceId):
    """
    Get device interfaces
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getARPStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface ARP statistics
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/arp_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getErrorStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface error stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/error_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV6Stats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface IPv6 stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/ipv6Stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPktSizes(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface packet size
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/pkt_size?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPortStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface port stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/port_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQosStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface QOS stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/qosStats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getQueueStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface queue stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/queue_stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceSerialInterface(vmanage, vpnId, ifname, af, deviceId):
    """
    Get serial interface
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/serial?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStats(vmanage, vpnId, ifname, af, deviceId):
    """
    Get interface stats
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/stats?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncedInterface(vmanage, vpnId, ifname, af, deviceId):
    """
    Get device interfaces synchronously
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	IF Name
	af  	        (string):	AF Type
	deviceId	    (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/synced?vpn-id={vpnId}&ifname={ifname}&af-type={af}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def trustsec(vmanage, deviceId):
    """
    Get policy filter memory usage from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/trustsec?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaceVPN(vmanage, deviceId):
    """
    Get device interfaces per VPN
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/interface/vpn?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getDbList(vmanage, deviceId):
    """
    Get OSPF database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/database?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDbExt(vmanage, deviceId):
    """
    Get OSPF external database list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/databaseexternal?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDbSummary(vmanage, deviceId):
    """
    Get OSPF database summary list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/databasesummary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterfaces(vmanage, deviceId):
    """
    Get OSPF interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNeighbors(vmanage, deviceId):
    """
    Get OSPF neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/neighbor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getProcess(vmanage, deviceId):
    """
    Get OSPF process list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/process?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRoutes(vmanage, deviceId):
    """
    Get OSPF route list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/routes?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV3Interface(vmanage, deviceId):
    """
    Get OSPF v3 interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/v3interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV3Neighbors(vmanage, deviceId):
    """
    Get OSPF v3 neighbor list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ospf/v3neighbor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getCtsPac(vmanage, deviceId):
    """
    get Cisco TrustSec PAC information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ctsPac?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getEnvData(vmanage, deviceId):
    """
    get Cisco TrustSec Environment Data information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/environmentData?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRadiusServer(vmanage, deviceId):
    """
    get Cisco TrustSec Environment Data Radius Server list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/environmentData/radiusServer?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRBCounters(vmanage, deviceId):
    """
    get Cisco TrustSec Role Based Counters information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/roleBasedCounters?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRBv6Counters(vmanage, deviceId):
    """
    get Cisco TrustSec Role Based Ipv6 Counters information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/roleBasedIpv6Counters?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRBv6Perms(vmanage, deviceId):
    """
    get Cisco TrustSec Role Based ipv6 Permissions information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/roleBasedIpv6Permissions?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRBPermissions(vmanage, deviceId):
    """
    get Cisco TrustSec Role Based Permissions information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/roleBasedPermissions?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRBSgtMap(vmanage, deviceId):
    """
    get Cisco TrustSec Role Based SGT Map information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/roleBasedSgtMap?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSxpConnections(vmanage, deviceId):
    """
    get Cisco TrustSec SXP Connections information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/sxpConnections?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getCflowdDPIDeviceFieldJSON(vmanage, isDeviceDashBoard):
    """
    Get Cflowd DPI query field JSON
    
    Parameters:
    isDeviceDashBoard	 (boolean):	Flag whether it is device dashboard request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/application/fields?isDeviceDashBoard={isDeviceDashBoard}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCollectorList(vmanage, deviceId):
    """
    Get cflowd collector list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/collector?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDPIFieldJSON(vmanage, isDeviceDashBoard):
    """
    Get CflowdvDPI query field JSON
    
    Parameters:
    isDeviceDashBoard	 (boolean):	Flag whether it is device dashboard request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/device/fields?isDeviceDashBoard={isDeviceDashBoard}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlows(vmanage, vpnId, src, dest, deviceId):
    """
    Get list of cflowd flows from device
    
    Parameters:
    vpnId	        (string):	VPN Id
	src	            (string):	Source IP
	dest	        (string):	Destination IP
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/flows?vpn-id={vpnId}&src-ip={src}&dest-ip={dest}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlowsCount(vmanage, vpnId, src, dest, deviceId):
    """
    Get cflowd flow count from device
    
    Parameters:
    vpnId	        (string):	VPN Id
	src	            (string):	Source IP
	dest	        (string):	Destination IP
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/flows-count?vpn-id={vpnId}&src-ip={src}&dest-ip={dest}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFnFCacheStats(vmanage, deviceId):
    """
    Get FnF cache stats from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/fnf/cache-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFnFExportClientStats(vmanage, deviceId):
    """
    Get FnF export client stats from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/fnf/export-client-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFnFExportStats(vmanage, deviceId):
    """
    Get FnF export stats from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/fnf/export-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFnf(vmanage, deviceId):
    """
    Get FnF from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/fnf/flow-monitor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFnFMonitorStats(vmanage, deviceId):
    """
    Get FnF monitor stats from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/fnf/monitor-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatistics(vmanage, deviceId):
    """
    Get cflowd statistics from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTemplate(vmanage, deviceId):
    """
    Get cflowd template from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cflowd/template?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getStatisticsType(vmanage):
    """
    Get statistics types
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/statistics"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getActiveAlarms(vmanage, scrollId, startDate, endDate, count, timeZone):
    """
    Get active alarms
    
    Parameters:
    scrollId	 (string):	SrollId
	startDate	 (string):	Start date
	endDate	 (string):	End date
	count	 (integer):	count
	timeZone	 (string):	Time zone
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/statistics/alarm/active?scrollId={scrollId}&startDate={startDate}&endDate={endDate}&count={count}&timeZone={timeZone}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatsData(vmanage, state_data_type, scrollId, startDate, endDate, count, timeZone):
    """
    Get device statistics data
    
    Parameters:
    state_data_type	 (string):	State data type
	scrollId	 (string):	Scroll Id
	startDate	 (string):	Start date
	endDate	 (string):	End date
	Parameter Description
	timeZone	 (string):	Time zone
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/statistics/{state_data_type}?scrollId={scrollId}&startDate={startDate}&endDate={endDate}&count={count}&timeZone={timeZone}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCountWithStateDataType(vmanage, state_data_type, startDate, endDate, timeZone):
    """
    Get response count of a query
    
    Parameters:
    state_data_type	 (string):	State data type
	startDate	 (string):	Start date
	endDate	 (string):	End date
	timeZone	 (string):	Time zone
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/statistics/{state_data_type}/doccount?startDate={startDate}&endDate={endDate}&timeZone={timeZone}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFieldsByType(vmanage, state_data_type):
    """
    Get statistics fields and types
    
    Parameters:
    state_data_type	 (string):	State data type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/data/device/statistics/{state_data_type}/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getSigDataCenterList(vmanage, type):
    """
    Get list of data centers for zscaler or umbrella
    
    Parameters:
    type	 (string):	Provider type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/sig/datacenters/{type}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getInterfaceList(vmanage, deviceId):
    """
    Get PIM interface list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pim/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNeighborList(vmanage, deviceId):
    """
    Get PIM neighbor list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pim/neighbor?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRpMappingList(vmanage, deviceId):
    """
    Get PIM Rp-mapping list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pim/rp-mapping?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatsList(vmanage, deviceId):
    """
    Get PIM statistics list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/pim/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getPPPInterfaceList(vmanage, deviceId):
    """
    Get PPP interface list from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ppp/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
